@@ -1,6 +1,8 @@
+# frozen_string_literal: true
+
 module Enumerize
   class Attribute
-    attr_reader :klass, :name, :values, :default_value, :i18n_scope
+    attr_reader :klass, :name, :values, :default_value, :i18n_scope, :skip_validations_value
 
     def initialize(klass, name, options={})
       raise ArgumentError, ':in option is required' unless options[:in]
@@ -11,21 +13,23 @@ module Enumerize
       @klass  = klass
       @name   = name.to_sym
 
-      value_class = options.fetch(:value_class, Value)
-      @values = Array(options[:in]).map { |v| value_class.new(self, *v) }
-
-      @value_hash = Hash[@values.map { |v| [v.value.to_s, v] }]
-      @value_hash.merge! Hash[@values.map { |v| [v.to_s, v] }]
-
       if options[:i18n_scope]
         raise ArgumentError, ':i18n_scope option accepts only String or Array of strings' unless Array(options[:i18n_scope]).all? { |s| s.is_a?(String) }
         @i18n_scope = options[:i18n_scope]
       end
 
+      value_class = options.fetch(:value_class, Value)
+      @values = Array(options[:in]).map { |v| value_class.new(self, *v).freeze }
+
+      @value_hash = Hash[@values.map { |v| [v.value.to_s, v] }]
+      @value_hash.merge! Hash[@values.map { |v| [v.to_s, v] }]
+
       if options[:default]
         @default_value = find_default_value(options[:default])
         raise ArgumentError, 'invalid default value' unless @default_value
       end
+
+      @skip_validations_value = options.fetch(:skip_validations, false)
     end
 
     def find_default_value(value)
@@ -44,11 +48,15 @@ module Enumerize
       values.map { |value| find_value(value) }.compact
     end
 
+    def each_value
+      values.each { |value| yield value }
+    end
+
     def i18n_scopes
       @i18n_scopes ||= if i18n_scope
-        scopes = Array(i18n_scope)
+        Array(i18n_scope)
       elsif @klass.respond_to?(:model_name)
-        scopes = ["enumerize.#{@klass.model_name.i18n_key}.#{name}"]
+        ["enumerize.#{@klass.model_name.i18n_key}.#{name}"]
       else
         []
       end
