@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Enumerize
   module Scope
     module Mongoid
@@ -16,6 +18,7 @@ module Enumerize
       private
 
       def _define_mongoid_scope_methods!(name, options)
+        return _define_mongoid_shallow_scopes!(name) if options[:scope] == :shallow
         scope_name = options[:scope] == true ? "with_#{name}" : options[:scope]
 
         define_singleton_method scope_name do |*values|
@@ -30,6 +33,14 @@ module Enumerize
           end
         end
       end
+
+      def _define_mongoid_shallow_scopes!(attribute_name)
+        enumerized_attributes[attribute_name].each_value do |value_obj|
+          define_singleton_method(value_obj) do
+            self.in(attribute_name => value_obj.value)
+          end
+        end
+      end
     end
   end
 end
