@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'i18n'
 
 module Enumerize
@@ -11,10 +13,16 @@ module Enumerize
       @value = value.nil? ? name.to_s : value
 
       super(name.to_s)
+
+      @i18n_keys = @attr.i18n_scopes.map { |s| :"#{s}.#{self}" }
+      @i18n_keys << :"enumerize.defaults.#{@attr.name}.#{self}"
+      @i18n_keys << :"enumerize.#{@attr.name}.#{self}"
+      @i18n_keys << self.underscore.humanize # humanize value if there are no translations
+      @i18n_keys
     end
 
     def text
-      I18n.t(i18n_keys[0], :default => i18n_keys[1..-1])
+      I18n.t(@i18n_keys[0], :default => @i18n_keys[1..-1])
     end
 
     def ==(other)
@@ -30,19 +38,5 @@ module Enumerize
     def predicate_call(value)
       value == self
     end
-
-    def i18n_keys
-      @i18n_keys ||= begin
-        i18n_keys = i18n_scopes
-        i18n_keys << :"enumerize.defaults.#{@attr.name}.#{self}"
-        i18n_keys << :"enumerize.#{@attr.name}.#{self}"
-        i18n_keys << self.underscore.humanize # humanize value if there are no translations
-        i18n_keys
-      end
-    end
-
-    def i18n_scopes
-      @attr.i18n_scopes.map { |s| :"#{s}.#{self}" }
-    end
   end
 end
