@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'test_helper'
 
 begin
@@ -16,9 +18,11 @@ describe Enumerize do
 
     key :sex
     key :role
+    key :foo
 
-    enumerize :sex, :in => %w[male female]
+    enumerize :sex,  :in => %w[male female]
     enumerize :role, :in => %w[admin user], :default => 'user'
+    enumerize :foo,  :in => %w[bar baz], :skip_validations => true
   end
 
   before { $VERBOSE = nil }
@@ -60,6 +64,12 @@ describe Enumerize do
     user.wont_be :valid?
   end
 
+  it 'does not validate inclusion when :skip_validations option passed' do
+    user = model.new
+    user.foo = 'wrong'
+    user.must_be :valid?
+  end
+
   it 'assigns value on loaded record' do
     model.delete_all
     model.create!(:sex => :male)
